#define  	iVWMA "iVWMA.ex5"
#resource "\\" + iVWMA

enum CENUM_APPLIED_PRICE {
	// MQL ENUM_APPLIED_PRICE values
  price_CLOSE,
  price_OPEN,
  price_HIGH,
  price_LOW,
  price_MEDIAN,
  price_TYPICAL,
  price_WEIGHTED,
  price_AVERAGE,
	// ADDED CUSTOM HEIKEN ASHI PRICE values
  priceHA_CLOSE,
  priceHA_OPEN,
  priceHA_HIGH,
  priceHA_LOW,
  priceHA_MEDIAN,
  priceHA_TYPICAL,
  priceHA_WEIGHTED,
  priceHA_AVERAGE
};

struct SParamVWMA_Tx {
	int									fastPeriod;									// Fast MA Period
	ENUM_MA_METHOD			fastMAMethod;							  // Fast MA Applied MAMethod
	int									midPeriod;									// Fast MA Period
	ENUM_MA_METHOD			midMAMethod;							  // Fast MA Applied MAMethod
	int									slowPeriod;									// Fast MA Period
	ENUM_MA_METHOD			slowMAMethod;							  // Fast MA Applied MAMethod
	CENUM_APPLIED_PRICE	appliedPrice;								// Applied price for all three MAs
	ENUM_APPLIED_VOLUME appliedVolume;							// Applied volume for all three MAs
};

#define 	_bufferVWMA		0
//+-----------------------------------------------------------------------------------------------------------------------------+
//| CLASS:				CiVWMA_Tx
//| APPLICATION:	Class for Tripple (Fast,Mid & Slow) Volume Weighted Moving Average Indicator 
//+-----------------------------------------------------------------------------------------------------------------------------+
class CiVWMA_Tx {

public:
	  CiVWMA_Tx() {	}
	  CiVWMA_Tx(string pSymbol,ENUM_TIMEFRAMES pTimeFrame,SParamVWMA_Tx &pParamVWMA_Tx);
	 ~CiVWMA_Tx();

private:
		string								mSymbol;
		ENUM_TIMEFRAMES				mTimeFrame;
		int										mDigits;

		int 									mHandleFast;
		int 									mHandleMid;
  	int										mHandleSlow;

public:
  	double 								getFast(int pIdx);
  	double 								getMid(int pIdx);
  	double 								getSlow(int pIdx);

}; // END Of Class Definition
//+-----------------------------------------------------------------------------------------------------------------------------+
//| METHOD:				Init()
//| APPLICATION:	METHOD TO INITIALIAZE MEMBER VARIABLES OF THE INDICATOR CLASS
//+-----------------------------------------------------------------------------------------------------------------------------+
CiVWMA_Tx::CiVWMA_Tx(string pSymbol,ENUM_TIMEFRAMES pTimeFrame,SParamVWMA_Tx &pParamVWMA_Tx) {

		mSymbol 	 = pSymbol;
		mTimeFrame = pTimeFrame;
    mDigits 	 = (int)SymbolInfoInteger(mSymbol,SYMBOL_DIGITS);

		TesterHideIndicators(true);
		ResetLastError();
		mHandleFast = iCustom(mSymbol,mTimeFrame,"::" + iVWMA,pParamVWMA_Tx.fastPeriod,
																															pParamVWMA_Tx.fastMAMethod,
																															pParamVWMA_Tx.appliedPrice,
																															pParamVWMA_Tx.appliedVolume);

		mHandleMid  = iCustom(mSymbol,mTimeFrame,"::" + iVWMA,pParamVWMA_Tx.midPeriod,
																															pParamVWMA_Tx.midMAMethod,
																															pParamVWMA_Tx.appliedPrice,
																															pParamVWMA_Tx.appliedVolume);

		mHandleSlow = iCustom(mSymbol,mTimeFrame,"::" + iVWMA,pParamVWMA_Tx.slowPeriod,
																															pParamVWMA_Tx.slowMAMethod,
																															pParamVWMA_Tx.appliedPrice,
																															pParamVWMA_Tx.appliedVolume);

	  if(mHandleFast == INVALID_HANDLE || mHandleMid == INVALID_HANDLE || mHandleSlow == INVALID_HANDLE) {
	   	string vMethod = "[" + mSymbol + "," + EnumToString(mTimeFrame) + "] " + __FUNCTION__;
	    PrintFormat("%s Error[#%i] Creating handle CiVWMA_Tx Fast or Mid or Slow",vMethod,GetLastError());
	  }
		TesterHideIndicators(false);

} // END Of method InitClass()
//+-----------------------------------------------------------------------------------------------------------------------------+
//| METHOD:				~CiVWMA_Tx()
//| APPLICATION:	DECONSTRUCTOR METHOD
//+-----------------------------------------------------------------------------------------------------------------------------+
CiVWMA_Tx::~CiVWMA_Tx() {

		IndicatorRelease(mHandleFast);
		IndicatorRelease(mHandleMid);
		IndicatorRelease(mHandleSlow);

} // END Of method ~CiVWMA_Tx()
//+-----------------------------------------------------------------------------------------------------------------------------+
//| METHOD:  			getSlow()
//| APPLICATION:  METHOD TO RETURN VOLUME WEIGHTED MA VALUE ON SPECIFIED INDEX
//+-----------------------------------------------------------------------------------------------------------------------------+
double CiVWMA_Tx::getSlow(int pIdx) {

	  double arrayData[1];

		ResetLastError();
	  if(CopyBuffer(mHandleSlow,_bufferVWMA,pIdx,1,arrayData) == -1) {
      string vMethod = "[" + mSymbol + "," + EnumToString(mTimeFrame) + "] " + __FUNCTION__;
	    PrintFormat("%s Error[#%i] getting iVWMA_PeriodTX Slow at Index[%i]",vMethod,GetLastError(),pIdx);
	    return(0.00);
	  }

  	return(NormalizeDouble(arrayData[0],mDigits));

} // END Of method getSlow()
//+-----------------------------------------------------------------------------------------------------------------------------+
//| METHOD:  			getMid()
//| APPLICATION:  METHOD TO RETURN MA VALUE ON SPECIFIED INDEX
//+-----------------------------------------------------------------------------------------------------------------------------+
double CiVWMA_Tx::getMid(int pIdx) {

  	double arrayData[1];

		ResetLastError();
	  if(CopyBuffer(mHandleMid,_bufferVWMA,pIdx,1,arrayData) == -1) {
      string vMethod = "[" + mSymbol + "," + EnumToString(mTimeFrame) + "] " + __FUNCTION__;
	    PrintFormat("%s Error[#%i] getting iVWMA_PeriodTX Mid at Index[%i]",vMethod,GetLastError(),pIdx);
    	return(0.00);
	  }

  	return(NormalizeDouble(arrayData[0],mDigits));

} // END Of method getMid()
//+-----------------------------------------------------------------------------------------------------------------------------+
//| METHOD:  			getFast()
//| APPLICATION:  METHOD TO RETURN MA VALUE ON SPECIFIED INDEX
//+-----------------------------------------------------------------------------------------------------------------------------+
double CiVWMA_Tx::getFast(int pIdx) {

  	double arrayData[1];

		ResetLastError();
	  if(CopyBuffer(mHandleFast,_bufferVWMA,pIdx,1,arrayData) == -1) {
      string vMethod = "[" + mSymbol + "," + EnumToString(mTimeFrame) + "] " + __FUNCTION__;
	    PrintFormat("%s Error[#%i] getting iVWMA_PeriodTX Fast at Index[%i]",vMethod,GetLastError(),pIdx);
    	return(0.00);
	  }

  	return(NormalizeDouble(arrayData[0],mDigits));

} // END Of method getFast()
//+-----------------------------------------------------------------------------------------------------------------------------+
